@@ -103,13 +103,14 @@ enum {
     EEAV_LPART_TOO_MANY_DOTS,
     EEAV_LPART_MISPLACED_DOT,
     EEAV_LPART_UNQUOTED_FWS,
+    EEAV_LPART_INVALID_FOLDING,
     EEAV_LPART_INVALID_UTF8,
     EEAV_DOMAIN_EMPTY,
     EEAV_DOMAIN_LABEL_TOO_LONG,
     EEAV_DOMAIN_MISPLACED_HYPHEN,
     EEAV_DOMAIN_MISPLACED_DELIMITER,
-    EEAV_DOMAIN_INVALID_CHAR,
-    EEAV_DOMAIN_TOO_LONG, /* 20 */
+    EEAV_DOMAIN_INVALID_CHAR, /* 20 */
+    EEAV_DOMAIN_TOO_LONG,
     EEAV_DOMAIN_NUMERIC,
     EEAV_DOMAIN_NOT_FQDN,
     EEAV_IPADDR_INVALID,
@@ -118,8 +119,8 @@ enum {
     EEAV_TLD_NOT_ASSIGNED,
     EEAV_TLD_COUNTRY_CODE,
     EEAV_TLD_GENERIC,
-    EEAV_TLD_GENERIC_RESTRICTED,
-    EEAV_TLD_INFRASTRUCTURE, /* 30 */
+    EEAV_TLD_GENERIC_RESTRICTED, /* 30 */
+    EEAV_TLD_INFRASTRUCTURE,
     EEAV_TLD_SPONSORED,
     EEAV_TLD_TEST,
     EEAV_TLD_SPECIAL,
